SonarrCommandHandler_EpisodeFile class

Facilitates, encapsulates, and manages individual calls related to episode files within Sonarr.

SonarrCommandHandler_EpisodeFile internally handles routing the HTTP client to the API calls.

Constructors

SonarrCommandHandler_EpisodeFile(Dio _client)
Create a series command handler using an initialized Dio client.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteEpisodeFile({required int episodeFileId}) → Future<void>
Handler for episodefile/{id}.
getEpisodeFile({required int episodeId}) → Future<SonarrEpisodeFile>
Handler for episodefile/{id}.
getSeriesEpisodeFiles({required int seriesId}) → Future<List<SonarrEpisodeFile>>
Handler for episodefile?seriesid={id}.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited