deleteQueue method
Handler for queue.
Deletes an item from the queue and download client..
Implementation
Future<void> deleteQueue({
required int id,
bool? blacklist,
}) async => _commandDeleteQueue(_client, id: id, blacklist: blacklist);
Handler for queue.
Deletes an item from the queue and download client..
Future<void> deleteQueue({
required int id,
bool? blacklist,
}) async => _commandDeleteQueue(_client, id: id, blacklist: blacklist);